package com.ruoyi.web.controller.place;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.place.TdPlaceRegist;
import com.ruoyi.web.controller.manager.TdPlaceRegistManager;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * packageName com.ruoyi.web.controller.place
 *
 * @author wangxy
 * @version JDK 8
 * @className TdPlaceRegistController
 * @date 2024/8/13
 * @description 涉密人员出入登记
 */
@Controller
@RequestMapping("/system/placeRegist")
public class TdPlaceRegistController extends BaseController {


    private String prefix = "system/placeRegist";


    @Resource
    private TdPlaceRegistManager placeRegistManager;


    @RequiresPermissions("system:placeRegist:view")
    @GetMapping()
    public String placeRegist() {
        return prefix + "/placeRegist";
    }

    /**
     * 场所出入登记列表
     */
    @RequiresPermissions("system:placeRegist:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdPlaceRegist tdPlaceRegist) {
        startPage();
        List<TdPlaceRegist> tdPlaceRegists = placeRegistManager.selectTdPlaceRegistList(tdPlaceRegist);
        return getDataTable(tdPlaceRegists);
    }


    /**
     * 新增场所出入登记
     */
    @GetMapping("/add")
    public String add() {
        return prefix + "/add";
    }

    /**
     * 新增场所出入登记
     */
    @RequiresPermissions("system:placeRegist:add")
    @Log(title = "场所出入登记", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TdPlaceRegist tdPlaceRegist) {
        return toAjax(placeRegistManager.saveOrUpdate(tdPlaceRegist));
    }

    /**
     * 修改场所出入登记
     */
    @RequiresPermissions("system:placeRegist:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap) {
        TdPlaceRegist tdPlaceRegist = placeRegistManager.selectTdPlaceRegist(id);
        mmap.put("tdPlaceRegist", tdPlaceRegist);
        return prefix + "/edit";
    }

    /**
     * 修改出入登记
     */
    @RequiresPermissions("system:placeRegist:edit")
    @Log(title = "场所出入登记", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TdPlaceRegist tdPlaceRegist) {
        return toAjax(placeRegistManager.saveOrUpdate(tdPlaceRegist));
    }

    /**
     * 详情场所出入登记
     */
    @RequiresPermissions("system:placeRegist:detail")
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap) {
        TdPlaceRegist tdPlaceRegist = placeRegistManager.selectTdPlaceRegist(id);
        mmap.put("tdPlaceRegist", tdPlaceRegist);
        return prefix + "/detail";
    }

    /**
     * 删除场所出入登记
     */
    @RequiresPermissions("system:placeRegist:remove")
    @Log(title = "场所出入登记", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids) {
        return toAjax(placeRegistManager.deleteTdPlaceRegistByids(ids));
    }



}
